import * as api from './api'
import {AddReq, CreateCrudOptionsProps, CreateCrudOptionsRet, DelReq, EditReq, UserPageQuery} from '@fast-crud/fast-crud'
import {inject} from 'vue'
import {BaseColumn} from '/@/views/adManage/utils/commonTabColumn.js'


export const createCrudOptions = function ({crudExpose, context}: CreateCrudOptionsProps): CreateCrudOptionsRet {
    const pageRequest = async (query: UserPageQuery) => {
        query['profile'] = context['profileId']
        query['start'] = context['start']
        query['end'] = context['end']
        return await api.GetList(query)
    }
    const editRequest = async ({form, row}: EditReq) => {
        form.id = row.id
        return await api.UpdateObj(form)
    }
    const delRequest = async ({row}: DelReq) => {
        return await api.DelObj(row.id)
    }
    const addRequest = async ({form}: AddReq) => {
        return await api.AddObj(form)
    }

    //权限判定
    const hasPermissions = inject('$hasPermissions')

    return {
        crudOptions: {
            table: {
                height: 800
            },
            container: {
                fixedHeight: false
            },
            actionbar: {
                show: true,
                buttons: {
                    add: {
                        show: false
                    },
                    create: {
                        text: '新建广告活动',
                        type: 'primary',
                        show: true,
                        click() {

                        }
                    }
                }
            },
            search: {
                show: false
            },
            toolbar: {
                buttons: {
                    search: {
                        show: true
                    },
                    compact: {
                        show: false
                    }
                }
            },
            request: {
                pageRequest,
                addRequest,
                editRequest,
                delRequest,
            },
            rowHandle: {
                fixed: 'right',
                width: 80,
                buttons: {
                    view: {
                        show: false,
                    },
                    edit: {
                        iconRight: 'Edit',
                        type: 'text',
                        text: null
                        // show: hasPermissions('dictionary:Update'),
                    },
                    remove: {
                        iconRight: 'Delete',
                        type: 'text',
                        text: null
                        // show: hasPermissions('dictionary:Delete'),
                    },
                },
            },
            columns: {
                id: {
                    title: 'ID',
                    column: {
                        show: false
                    },
                    form: {
                        show: false
                    }
                },
                campaignName: {
                    title: '广告活动',
                    column: {
                        width: '200px',
                        fixed: 'left',
                        align: 'center',
                    },
                    search: {
                        show: true,
                        component: {
                            props: {
                                clearable: true
                            }
                        }
                    },
                    form: {
                        rules: [{required: true, message: '必填项'}]
                    }
                },
                placementClassification: {
                    title: '广告位',
                    column: {
                        align: 'center',
                    },
                },
                dynBidStrategy: {
                    title: '竞价策略',
                    column: {
                        align: 'center',
                    },
                },
                '竞价调整': {},
                Impression: {
                    title: '曝光量',
                    column: {
                        align: 'center',
                    },
                },
                Click: {
                    title: '点击量',
                    column: {
                        align: 'center',
                    },
                },
                CTR: {title: '点击率', column: {align: 'center'}},
                Spend: {title: '花费', column: {align: 'center'}},
                CPC: {title: '点击成本', column: {align: 'center'}},
                TotalPurchases: {title: '订单数', column: {align: 'center'}},
                TotalSales: {title: '销售额', column: {align: 'center'}},
                TotalUnitOrdered: {title: '销量', column: {align: 'center'}},
                PurchasesRate: {title: '转化率', column: {align: 'center'}},
                ACOS: {title: 'ACOS', column: {align: 'center'}},
                ROAS: {title: 'ROAS', column: {align: 'center'}},
                CPA: {title: '订单成本', column: {align: 'center'}},
                ...BaseColumn
            }
        }
    }
}
